@@ -57,8 +57,9 @@ $left_column = (new CFormList())
 			'object_name' => 'hosts',
 			'data' => array_key_exists('hosts', $data) ? $data['hosts'] : [],
 			'popup' => [
-				'filter_preselect_fields' => [
-					'hostgroups' => 'groupids_'
+				'filter_preselect' => [
+					'id' => 'groupids_',
+					'submit_as' => 'groupid'
 				],
 				'parameters' => [
 					'srctbl' => 'hosts',
@@ -77,8 +78,9 @@ $left_column = (new CFormList())
 			'object_name' => 'triggers',
 			'data' => array_key_exists('triggers', $data) ? $data['triggers'] : [],
 			'popup' => [
-				'filter_preselect_fields' => [
-					'hosts' => 'hostids_'
+				'filter_preselect' => [
+					'id' => 'hostids_',
+					'submit_as' => 'hostid'
 				],
 				'parameters' => [
 					'srctbl' => 'triggers',
@@ -123,6 +125,24 @@ $left_column
 		$filter_age,
 		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 		_('days')
+	])
+	->addRow(_('Show symptoms'), [
+		(new CCheckBox('show_symptoms'))
+			->setChecked($data['show_symptoms'] == 1)
+			->setUncheckedValue(0)
+			->setId('show_symptoms_#{uniqid}')
+	])
+	->addRow(_('Show suppressed problems'), [
+		(new CCheckBox('show_suppressed'))
+			->setChecked($data['show_suppressed'] == ZBX_PROBLEM_SUPPRESSED_TRUE)
+			->setUncheckedValue(0)
+			->setId('show_suppressed_#{uniqid}')
+	])
+	->addRow(_('Show unacknowledged only'), [
+		(new CCheckBox('unacknowledged'))
+			->setChecked($data['unacknowledged'] == 1)
+			->setUncheckedValue(0)
+			->setId('unacknowledged_#{uniqid}')
 	]);
 
 $filter_inventory_table = new CTable();
@@ -247,20 +267,7 @@ $right_column = (new CFormList())
 			->setEnabled($data['compact_view'] == 0)
 			->removeId()
 	])
-	->addRow(_('Show suppressed problems'), [
-		(new CCheckBox('show_suppressed'))
-			->setChecked($data['show_suppressed'] == ZBX_PROBLEM_SUPPRESSED_TRUE)
-			->setUncheckedValue(0)
-			->setId('show_suppressed_#{uniqid}'),
-		(new CDiv([
-			(new CLabel(_('Show unacknowledged only'), 'unacknowledged_#{uniqid}'))
-				->addClass(ZBX_STYLE_SECOND_COLUMN_LABEL),
-			(new CCheckBox('unacknowledged'))
-				->setChecked($data['unacknowledged'] == 1)
-				->setUncheckedValue(0)
-				->setId('unacknowledged_#{uniqid}')
-		]))->addClass(ZBX_STYLE_TABLE_FORMS_SECOND_COLUMN)
-	])
+
 	->addRow(_('Compact view'), [
 		(new CCheckBox('compact_view'))
 			->setChecked($data['compact_view'] == 1)
@@ -269,7 +276,7 @@ $right_column = (new CFormList())
 		(new CDiv([
 			(new CLabel(_('Show timeline'), 'show_timeline_#{uniqid}'))->addClass(ZBX_STYLE_SECOND_COLUMN_LABEL),
 			(new CCheckBox('show_timeline'))
-				->setChecked($data['show_timeline'] == 1)
+				->setChecked($data['show_timeline'] == ZBX_TIMELINE_ON)
 				->setEnabled($data['compact_view'] == 0)
 				->setUncheckedValue(0)
 				->setId('show_timeline_#{uniqid}')
@@ -301,7 +308,6 @@ $template = (new CDiv())
 		(new CDiv($right_column))->addClass(ZBX_STYLE_CELL)
 	]);
 $template = (new CForm('get'))
-	->cleanItems()
 	->setName('zbx_filter')
 	->addItem([
 		$template,
@@ -324,12 +330,12 @@ if (array_key_exists('render_html', $data)) {
 	return;
 }
 
-(new CScriptTemplate('filter-monitoring-problem'))
+(new CTemplateTag('filter-monitoring-problem'))
 	->setAttribute('data-template', 'monitoring.problem.filter')
 	->addItem($template)
 	->show();
 
-(new CScriptTemplate('filter-inventory-row'))
+(new CTemplateTag('filter-inventory-row'))
 	->addItem(
 		(new CRow([
 			(new CSelect('inventory[#{rowNum}][field]'))
@@ -347,7 +353,7 @@ if (array_key_exists('render_html', $data)) {
 	)
 	->show();
 
-(new CScriptTemplate('filter-tag-row-tmpl'))
+(new CTemplateTag('filter-tag-row-tmpl'))
 	->addItem(
 		(new CRow([
 			(new CTextBox('tags[#{rowNum}][tag]', '#{tag}'))
@@ -390,9 +396,9 @@ if (array_key_exists('render_html', $data)) {
 		$('[name="filter_new"],[name="filter_update"]').hide()
 			.filter(data.filter_configurable ? '[name="filter_update"]' : '[name="filter_new"]').show();
 
-		let fields = ['show', 'name', 'tag_priority', 'show_opdata', 'show_suppressed', 'show_tags', 'unacknowledged',
-				'compact_view', 'show_timeline', 'details', 'highlight_row', 'age_state', 'age', 'tag_name_format',
-				'evaltype'
+		let fields = ['show', 'name', 'tag_priority', 'show_opdata', 'show_symptoms', 'show_suppressed', 'show_tags',
+				'unacknowledged', 'compact_view', 'show_timeline', 'details', 'highlight_row', 'age_state', 'age',
+				'tag_name_format', 'evaltype'
 			],
 			eventHandler = {
 				show: () => {
@@ -525,8 +531,9 @@ if (array_key_exists('render_html', $data)) {
 			name: 'hostids[]',
 			data: data.filter_view_data.hosts || [],
 			popup: {
-				filter_preselect_fields: {
-					hostgroups: 'groupids_' + data.uniqid
+				filter_preselect: {
+					id: 'groupids_' + data.uniqid,
+					submit_as: 'groupid'
 				},
 				parameters: {
 					multiselect: 1,
@@ -545,8 +552,9 @@ if (array_key_exists('render_html', $data)) {
 			name: 'triggerids[]',
 			data: data.filter_view_data.triggers || [],
 			popup: {
-				filter_preselect_fields: {
-					hosts: 'hostids_' + data.uniqid
+				filter_preselect: {
+					id: 'hostids_' + data.uniqid,
+					submit_as: 'hostid'
 				},
 				parameters: {
 					srctbl: 'triggers',
