@@ -27,9 +27,9 @@ if ($data['uncheck']) {
 	uncheckTableRows('userrole');
 }
 
-$widget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('User roles'))
-	->setDocUrl(CDocHelper::getUrl(CDocHelper::ADMINISTRATION_USERROLE_LIST))
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::USERS_USERROLE_LIST))
 	->setControls(
 		(new CTag('nav', true,
 			(new CList())
@@ -126,9 +126,11 @@ $form->addItem([
 	$table,
 	$this->data['paging'],
 	new CActionButtonList('action', 'roleids', [
-		'userrole.delete' => ['name' => _('Delete'), 'confirm' => _('Delete selected roles?')]
+		'userrole.delete' => ['name' => _('Delete'), 'confirm' => _('Delete selected roles?'),
+			'csrf_token' => CCsrfTokenHelper::get('userrole')]
 	], 'userrole')
 ]);
 
-$widget->addItem($form);
-$widget->show();
+$html_page
+	->addItem($form)
+	->show();
