@@ -69,7 +69,7 @@ window.service_status_rule_edit_popup = new class {
 	submit() {
 		this.overlay.setLoading();
 
-		const curl = new Curl('zabbix.php', false);
+		const curl = new Curl('zabbix.php');
 
 		curl.setArgument('action', 'service.statusrule.validate');
 
