@@ -1331,7 +1331,7 @@ class CHistoryManager {
 	private function deleteHistoryFromSql(array $items) {
 		global $DB;
 
-		$item_tables = array_map('self::getTableName', array_unique($items));
+		$item_tables = array_map([self::class, 'getTableName'], array_unique($items));
 		$table_names = array_flip(self::getTableName());
 
 		if (in_array(ITEM_VALUE_TYPE_UINT64, $items)) {
@@ -1489,7 +1489,7 @@ class CHistoryManager {
 		}
 
 		$indices = [];
-		$endponts = [];
+		$endpoints = [];
 
 		foreach (array_unique($value_types) as $type) {
 			if (self::getDataSourceType($type) === ZBX_HISTORY_SOURCE_ELASTIC) {
@@ -1499,11 +1499,11 @@ class CHistoryManager {
 
 		foreach ($indices as $type => $index) {
 			if (($url = self::getElasticsearchUrl($index)) !== null) {
-				$endponts[$type] = $url.$index.'*/'.$action;
+				$endpoints[$type] = $url.$index.'*/'.$action;
 			}
 		}
 
-		return $endponts;
+		return $endpoints;
 	}
 
 	/**
