@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -71,6 +71,7 @@ class CTemplate extends CHostGeneral {
 			// output
 			'output'					=> API_OUTPUT_EXTEND,
 			'selectGroups'				=> null,
+			'selectTemplateGroups'		=> null,
 			'selectHosts'				=> null,
 			'selectTemplates'			=> null,
 			'selectParentTemplates'		=> null,
@@ -94,6 +95,8 @@ class CTemplate extends CHostGeneral {
 		$options = zbx_array_merge($defOptions, $options);
 		$this->validateGet($options);
 
+		$this->checkDeprecatedParam($options, 'selectGroups');
+
 		// editable + PERMISSION CHECK
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
@@ -251,6 +254,13 @@ class CTemplate extends CHostGeneral {
 		}
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
+
+		$upcased_index = array_search($this->tableAlias().'.name_upper', $sqlParts['select']);
+
+		if ($upcased_index !== false) {
+			unset($sqlParts['select'][$upcased_index]);
+		}
+
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$res = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($template = DBfetch($res)) {
@@ -278,6 +288,7 @@ class CTemplate extends CHostGeneral {
 
 		if ($result) {
 			$result = $this->addRelatedObjects($options, $result);
+			$result = $this->unsetExtraFields($result, ['name_upper']);
 		}
 
 		// removing keys (hash -> array)
@@ -298,7 +309,9 @@ class CTemplate extends CHostGeneral {
 	protected function validateGet(array $options) {
 		// Validate input parameters.
 		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
-			'selectValueMaps' =>			['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => 'valuemapid,name,mappings,uuid']
+			'selectTags' =>					['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', ['tag', 'value'])],
+			'selectValueMaps' =>			['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', ['valuemapid', 'name', 'mappings', 'uuid'])],
+			'selectParentTemplates' =>		['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL | API_ALLOW_COUNT, 'in' => implode(',', ['templateid', 'host', 'name', 'description', 'uuid'])]
 		]];
 		$options_filter = array_intersect_key($options, $api_input_rules['fields']);
 		if (!CApiInputValidator::validate($api_input_rules, $options_filter, '/', $error)) {
@@ -334,7 +347,7 @@ class CTemplate extends CHostGeneral {
 		$this->checkTemplatesLinks($templates);
 
 		$this->updateGroups($templates);
-		$this->updateTagsNew($templates);
+		$this->updateTags($templates);
 		$this->updateMacros($templates);
 		$this->updateTemplates($templates);
 
@@ -354,6 +367,8 @@ class CTemplate extends CHostGeneral {
 			'host' =>			['type' => API_H_NAME, 'flags' => API_REQUIRED, 'length' => DB::getFieldLength('hosts', 'host')],
 			'name' =>			['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('hosts', 'name'), 'default_source' => 'host'],
 			'description' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'description')],
+			'vendor_name' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_name')],
+			'vendor_version' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_version')],
 			'groups' =>			['type' => API_OBJECTS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid']], 'fields' => [
 				'groupid' =>		['type' => API_ID, 'flags' => API_REQUIRED]
 			]],
@@ -368,7 +383,7 @@ class CTemplate extends CHostGeneral {
 				'macro' =>			['type' => API_USER_MACRO, 'flags' => API_REQUIRED, 'length' => DB::getFieldLength('hostmacro', 'macro')],
 				'type' =>			['type' => API_INT32, 'in' => implode(',', [ZBX_MACRO_TYPE_TEXT, ZBX_MACRO_TYPE_SECRET, ZBX_MACRO_TYPE_VAULT]), 'default' => ZBX_MACRO_TYPE_TEXT],
 				'value' =>			['type' => API_MULTIPLE, 'flags' => API_REQUIRED, 'rules' => [
-										['if' => ['field' => 'type', 'in' => implode(',', [ZBX_MACRO_TYPE_VAULT])], 'type' => API_VAULT_SECRET, 'length' => DB::getFieldLength('hostmacro', 'value')],
+										['if' => ['field' => 'type', 'in' => implode(',', [ZBX_MACRO_TYPE_VAULT])], 'type' => API_VAULT_SECRET, 'provider' => CSettingsHelper::get(CSettingsHelper::VAULT_PROVIDER), 'length' => DB::getFieldLength('hostmacro', 'value')],
 										['else' => true, 'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hostmacro', 'value')]
 				]],
 				'description' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hostmacro', 'description')]
@@ -379,10 +394,10 @@ class CTemplate extends CHostGeneral {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		$this->checkGroups($templates);
-		$this->checkDuplicates($templates);
+		self::checkVendorFields($templates);
 		self::checkAndAddUuid($templates);
-
+		$this->checkDuplicates($templates);
+		$this->checkGroups($templates);
 		$this->checkTemplates($templates);
 	}
 
@@ -440,7 +455,7 @@ class CTemplate extends CHostGeneral {
 		}
 
 		$this->updateGroups($templates, $db_templates);
-		$this->updateTagsNew($templates, $db_templates);
+		$this->updateTags($templates, $db_templates);
 		$this->updateMacros($templates, $db_templates);
 		$this->updateTemplates($templates, $db_templates);
 
@@ -457,10 +472,13 @@ class CTemplate extends CHostGeneral {
 	 */
 	protected function validateUpdate(array &$templates, array &$db_templates = null) {
 		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['templateid'], ['host'], ['name']], 'fields' => [
+			'uuid' => 				['type' => API_UUID],
 			'templateid' =>			['type' => API_ID, 'flags' => API_REQUIRED],
 			'host' =>				['type' => API_H_NAME, 'length' => DB::getFieldLength('hosts', 'host')],
 			'name' =>				['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('hosts', 'name')],
 			'description' =>		['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'description')],
+			'vendor_name' =>		['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_name')],
+			'vendor_version' =>		['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_version')],
 			'groups' =>				['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid']], 'fields' => [
 				'groupid' =>			['type' => API_ID, 'flags' => API_REQUIRED]
 			]],
@@ -488,7 +506,7 @@ class CTemplate extends CHostGeneral {
 		}
 
 		$db_templates = $this->get([
-			'output' => ['templateid', 'host', 'name', 'description'],
+			'output' => ['templateid', 'host', 'name', 'description', 'vendor_name', 'vendor_version'],
 			'templateids' => array_column($templates, 'templateid'),
 			'editable' => true,
 			'preservekeys' => true
@@ -500,6 +518,7 @@ class CTemplate extends CHostGeneral {
 
 		$this->addAffectedObjects($templates, $db_templates);
 
+		self::checkVendorFields($templates, $db_templates);
 		$this->checkDuplicates($templates, $db_templates);
 		$this->checkGroups($templates, $db_templates);
 		$this->checkTemplates($templates, $db_templates);
@@ -507,6 +526,39 @@ class CTemplate extends CHostGeneral {
 		$templates = $this->validateHostMacros($templates, $db_templates);
 	}
 
+	/**
+	 * Check vendor fields for update or create operation.
+	 *
+	 * @param array      $templates
+	 * @param array|null $db_templates
+	 *
+	 * @throws Exception
+	 */
+	private static function checkVendorFields(array $templates, array $db_templates = null): void {
+		$vendor_fields = array_fill_keys(['vendor_name', 'vendor_version'], '');
+
+		foreach ($templates as $i => $template) {
+			if (!array_key_exists('vendor_name', $template) && !array_key_exists('vendor_version', $template)) {
+				continue;
+			}
+
+			$_template = array_intersect_key($template, $vendor_fields);
+
+			if ($db_templates === null) {
+				$_template += $vendor_fields;
+			}
+			else {
+				$_template += array_intersect_key($db_templates[$template['templateid']], $vendor_fields);
+			}
+
+			if (($_template['vendor_name'] === '') !== ($_template['vendor_version'] === '')) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _s('Invalid parameter "%1$s": %2$s.', '/'.($i + 1),
+					_('both vendor_name and vendor_version should be either present or empty')
+				));
+			}
+		}
+	}
+
 	/**
 	 * Delete template.
 	 *
@@ -527,19 +579,24 @@ class CTemplate extends CHostGeneral {
 			'nopermissions' => true,
 			'preservekeys' => true
 		]);
+
 		if ($del_rules) {
 			CDiscoveryRuleManager::delete(array_keys($del_rules));
 		}
 
 		// delete the items
-		$del_items = API::Item()->get([
-			'output' => [],
-			'templateids' => $templateids,
-			'nopermissions' => true,
+		$db_items = DB::select('items', [
+			'output' => ['itemid', 'name'],
+			'filter' => [
+				'hostid' => $templateids,
+				'flags' => ZBX_FLAG_DISCOVERY_NORMAL,
+				'type' => CItem::SUPPORTED_ITEM_TYPES
+			],
 			'preservekeys' => true
 		]);
-		if ($del_items) {
-			CItemManager::delete(array_keys($del_items));
+
+		if ($db_items) {
+			CItem::deleteForce($db_items);
 		}
 
 		// delete host from maps
@@ -611,15 +668,15 @@ class CTemplate extends CHostGeneral {
 			'operationid'=>$delOperationids
 		]);
 
-		// http tests
-		$delHttpTests = API::HttpTest()->get([
-			'templateids' => $templateids,
-			'output' => ['httptestid'],
-			'nopermissions' => 1,
+		// delete web scenarios
+		$db_httptests = DB::select('httptest', [
+			'output' => ['httptestid', 'name'],
+			'filter' => ['hostid' => $templateids],
 			'preservekeys' => true
 		]);
-		if (!empty($delHttpTests)) {
-			API::HttpTest()->delete(array_keys($delHttpTests), true);
+
+		if ($db_httptests) {
+			CHttpTest::deleteForce($db_httptests);
 		}
 
 		// Get host prototype operations from LLD overrides where this template is linked.
@@ -681,6 +738,7 @@ class CTemplate extends CHostGeneral {
 		}
 
 		// Finally delete the template.
+		DB::delete('host_tag', ['hostid' => $templateids]);
 		DB::delete('hosts', ['hostid' => $templateids]);
 
 		$this->addAuditLog(CAudit::ACTION_DELETE, CAudit::RESOURCE_TEMPLATE, $db_templates);
@@ -751,7 +809,7 @@ class CTemplate extends CHostGeneral {
 	}
 
 	/**
-	 * Add given host groups, macros and templates to given templates.
+	 * Add given template groups, macros and templates to given templates.
 	 *
 	 * @param array $data
 	 *
@@ -772,7 +830,7 @@ class CTemplate extends CHostGeneral {
 	}
 
 	/**
-	 * Replace host groups, macros and templates on the given templates.
+	 * Replace template groups, macros and templates on the given templates.
 	 *
 	 * @param array $data
 	 *
@@ -793,7 +851,7 @@ class CTemplate extends CHostGeneral {
 	}
 
 	/**
-	 * Remove given host groups, macros and templates from given templates.
+	 * Remove given template groups, macros and templates from given templates.
 	 *
 	 * @param array $data
 	 *
@@ -820,7 +878,7 @@ class CTemplate extends CHostGeneral {
 	 * @throws APIException if the input is invalid.
 	 */
 	private function validateMassAdd(array &$data, ?array &$db_templates): void {
-		$api_input_rules = ['type' => API_OBJECT, 'flags' => API_NOT_EMPTY, 'fields' => [
+		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			'templates' =>		['type' => API_OBJECTS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['templateid']], 'fields' => [
 				'templateid' =>		['type' => API_ID, 'flags' => API_REQUIRED]
 			]],
@@ -831,7 +889,7 @@ class CTemplate extends CHostGeneral {
 				'macro' =>			['type' => API_USER_MACRO, 'flags' => API_REQUIRED, 'length' => DB::getFieldLength('hostmacro', 'macro')],
 				'type' =>			['type' => API_INT32, 'in' => implode(',', [ZBX_MACRO_TYPE_TEXT, ZBX_MACRO_TYPE_SECRET, ZBX_MACRO_TYPE_VAULT]), 'default' => ZBX_MACRO_TYPE_TEXT],
 				'value' =>			['type' => API_MULTIPLE, 'flags' => API_REQUIRED, 'rules' => [
-										['if' => ['field' => 'type', 'in' => implode(',', [ZBX_MACRO_TYPE_VAULT])], 'type' => API_VAULT_SECRET, 'length' => DB::getFieldLength('hostmacro', 'value')],
+										['if' => ['field' => 'type', 'in' => implode(',', [ZBX_MACRO_TYPE_VAULT])], 'type' => API_VAULT_SECRET, 'provider' => CSettingsHelper::get(CSettingsHelper::VAULT_PROVIDER), 'length' => DB::getFieldLength('hostmacro', 'value')],
 										['else' => true, 'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hostmacro', 'value')]
 				]],
 				'description' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hostmacro', 'description')]
@@ -859,7 +917,7 @@ class CTemplate extends CHostGeneral {
 		if (array_key_exists('groups', $data) && $data['groups']) {
 			$groupids = array_column($data['groups'], 'groupid');
 
-			$count = API::HostGroup()->get([
+			$count = API::TemplateGroup()->get([
 				'countOutput' => true,
 				'groupids' => $groupids,
 				'editable' => true
@@ -932,7 +990,7 @@ class CTemplate extends CHostGeneral {
 	 * @throws APIException if the input is invalid.
 	 */
 	private function validateMassUpdate(array &$data, ?array &$db_templates): void {
-		$api_input_rules = ['type' => API_OBJECT, 'flags' => API_NOT_EMPTY, 'fields' => [
+		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			'templates' =>		['type' => API_OBJECTS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['templateid']], 'fields' => [
 				'templateid' =>		['type' => API_ID, 'flags' => API_REQUIRED]
 			]],
@@ -943,7 +1001,7 @@ class CTemplate extends CHostGeneral {
 				'macro' =>			['type' => API_USER_MACRO, 'flags' => API_REQUIRED, 'length' => DB::getFieldLength('hostmacro', 'macro')],
 				'type' =>			['type' => API_INT32, 'in' => implode(',', [ZBX_MACRO_TYPE_TEXT, ZBX_MACRO_TYPE_SECRET, ZBX_MACRO_TYPE_VAULT]), 'default' => ZBX_MACRO_TYPE_TEXT],
 				'value' =>			['type' => API_MULTIPLE, 'flags' => API_REQUIRED, 'rules' => [
-										['if' => ['field' => 'type', 'in' => implode(',', [ZBX_MACRO_TYPE_VAULT])], 'type' => API_VAULT_SECRET, 'length' => DB::getFieldLength('hostmacro', 'value')],
+										['if' => ['field' => 'type', 'in' => implode(',', [ZBX_MACRO_TYPE_VAULT])], 'type' => API_VAULT_SECRET, 'provider' => CSettingsHelper::get(CSettingsHelper::VAULT_PROVIDER), 'length' => DB::getFieldLength('hostmacro', 'value')],
 										['else' => true, 'type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hostmacro', 'value')]
 				]],
 				'description' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hostmacro', 'description')]
@@ -974,7 +1032,7 @@ class CTemplate extends CHostGeneral {
 		if (array_key_exists('groups', $data)) {
 			$groupids = array_column($data['groups'], 'groupid');
 
-			$count = API::HostGroup()->get([
+			$count = API::TemplateGroup()->get([
 				'countOutput' => true,
 				'groupids' => $groupids
 			]);
@@ -1005,7 +1063,7 @@ class CTemplate extends CHostGeneral {
 			}
 
 			if ($edit_groupids) {
-				$count = API::HostGroup()->get([
+				$count = API::TemplateGroup()->get([
 					'countOutput' => true,
 					'groupids' => array_keys($edit_groupids),
 					'editable' => true
@@ -1091,7 +1149,7 @@ class CTemplate extends CHostGeneral {
 	 * @throws APIException if the input is invalid.
 	 */
 	private function validateMassRemove(array &$data, ?array &$db_templates): void {
-		$api_input_rules = ['type' => API_OBJECT, 'flags' => API_NOT_EMPTY, 'fields' => [
+		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			'templateids' =>		['type' => API_IDS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => true],
 			'groupids' =>			['type' => API_IDS, 'flags' => API_NORMALIZE, 'uniq' => true],
 			'macros' =>				['type' => API_USER_MACROS, 'flags' => API_NORMALIZE, 'uniq' => true, 'length' => DB::getFieldLength('hostmacro', 'macro')],
@@ -1115,7 +1173,7 @@ class CTemplate extends CHostGeneral {
 		}
 
 		if (array_key_exists('groupids', $data) && $data['groupids']) {
-			$count = API::HostGroup()->get([
+			$count = API::TemplateGroup()->get([
 				'countOutput' => true,
 				'groupids' => $data['groupids'],
 				'editable' => true
@@ -1127,7 +1185,7 @@ class CTemplate extends CHostGeneral {
 				);
 			}
 
-			CHostGroup::checkObjectsWithoutGroups('templates', $db_templates, $data['groupids']);
+			CTemplateGroup::checkTemplatesWithoutGroups($db_templates, $data['groupids']);
 
 			$this->massAddAffectedObjects('groups', $data['groupids'], $db_templates);
 		}
@@ -1171,9 +1229,12 @@ class CTemplate extends CHostGeneral {
 	protected function addRelatedObjects(array $options, array $result) {
 		$result = parent::addRelatedObjects($options, $result);
 
+		// adding template groups
+		$this->addRelatedGroups($options, $result, 'selectGroups');
+		$this->addRelatedGroups($options, $result, 'selectTemplateGroups');
+
 		$templateids = array_keys($result);
 
-		// Adding Templates
 		if ($options['selectTemplates'] !== null) {
 			if ($options['selectTemplates'] != API_OUTPUT_COUNT) {
 				$templates = [];
@@ -1208,7 +1269,6 @@ class CTemplate extends CHostGeneral {
 			}
 		}
 
-		// Adding Hosts
 		if ($options['selectHosts'] !== null) {
 			if ($options['selectHosts'] != API_OUTPUT_COUNT) {
 				$hosts = [];
@@ -1243,7 +1303,6 @@ class CTemplate extends CHostGeneral {
 			}
 		}
 
-		// Adding dashboards.
 		if ($options['selectDashboards'] !== null) {
 			if ($options['selectDashboards'] != API_OUTPUT_COUNT) {
 				$dashboards = API::TemplateDashboard()->get([
@@ -1278,6 +1337,59 @@ class CTemplate extends CHostGeneral {
 			}
 		}
 
+		if ($options['selectTags'] !== null) {
+			foreach ($result as &$row) {
+				$row['tags'] = [];
+			}
+			unset($row);
+
+			if ($options['selectTags'] === API_OUTPUT_EXTEND) {
+				$output = ['hosttagid', 'hostid', 'tag', 'value'];
+			}
+			else {
+				$output = array_unique(array_merge(['hosttagid', 'hostid'], $options['selectTags']));
+			}
+
+			$sql_options = [
+				'output' => $output,
+				'filter' => ['hostid' => $templateids]
+			];
+			$db_tags = DBselect(DB::makeSql('host_tag', $sql_options));
+
+			while ($db_tag = DBfetch($db_tags)) {
+				$hostid = $db_tag['hostid'];
+
+				unset($db_tag['hosttagid'], $db_tag['hostid']);
+
+				$result[$hostid]['tags'][] = $db_tag;
+			}
+		}
+
 		return $result;
 	}
+
+	/**
+	 * Adds related template groups requested by "select*" options to the resulting object set.
+	 *
+	 * @param array  $options [IN] Original input options.
+	 * @param array  $result  [IN/OUT] Result output.
+	 * @param string $option  [IN] Possible values:
+	 *                               - "selectGroups" (deprecated);
+	 *                               - "selectHostGroups" (or any other value).
+	 */
+	private function addRelatedGroups(array $options, array &$result, string $option): void {
+		if ($options[$option] === null || $options[$option] === API_OUTPUT_COUNT) {
+			return;
+		}
+
+		$relationMap = $this->createRelationMap($result, 'hostid', 'groupid', 'hosts_groups');
+		$groups = API::TemplateGroup()->get([
+			'output' => $options[$option],
+			'groupids' => $relationMap->getRelatedIds(),
+			'preservekeys' => true
+		]);
+
+		$output_tag = $option === 'selectGroups' ? 'groups' : 'templategroups';
+		$result = $relationMap->mapMany($result, $groups, $output_tag);
+	}
 }
