@@ -83,7 +83,9 @@ final class CItemData {
 			'system.stat[resource,<type>]',
 			'system.sw.arch',
 			'system.sw.os[<info>]',
+			'system.sw.os.get',
 			'system.sw.packages[<regexp>,<manager>,<format>]',
+			'system.sw.packages.get[<regexp>,<manager>]',
 			'system.swap.in[<device>,<type>]',
 			'system.swap.out[<device>,<type>]',
 			'system.swap.size[<device>,<type>]',
@@ -116,8 +118,8 @@ final class CItemData {
 			'web.page.get[host,<path>,<port>]',
 			'web.page.perf[host,<path>,<port>]',
 			'web.page.regexp[host,<path>,<port>,regexp,<length>,<output>]',
-			'wmi.get[<namespace>,<query>]',
-			'wmi.getall[<namespace>,<query>]',
+			'wmi.get[namespace,query]',
+			'wmi.getall[namespace,query]',
 			'zabbix.stats[<ip>,<port>,queue,<from>,<to>]',
 			'zabbix.stats[<ip>,<port>]'
 		],
@@ -185,7 +187,9 @@ final class CItemData {
 			'system.stat[resource,<type>]',
 			'system.sw.arch',
 			'system.sw.os[<info>]',
+			'system.sw.os.get',
 			'system.sw.packages[<regexp>,<manager>,<format>]',
+			'system.sw.packages.get[<regexp>,<manager>]',
 			'system.swap.in[<device>,<type>]',
 			'system.swap.out[<device>,<type>]',
 			'system.swap.size[<device>,<type>]',
@@ -218,7 +222,7 @@ final class CItemData {
 			'web.page.get[host,<path>,<port>]',
 			'web.page.perf[host,<path>,<port>]',
 			'web.page.regexp[host,<path>,<port>,regexp,<length>,<output>]',
-			'wmi.get[<namespace>,<query>]',
+			'wmi.get[namespace,query]',
 			'zabbix.stats[<ip>,<port>,queue,<from>,<to>]',
 			'zabbix.stats[<ip>,<port>]'
 		],
@@ -356,6 +360,7 @@ final class CItemData {
 		],
 		ITEM_TYPE_INTERNAL => [
 			'zabbix[boottime]',
+			'zabbix[connector_queue]',
 			'zabbix[host,,items]',
 			'zabbix[host,,items_unsupported]',
 			'zabbix[host,,maintenance]',
@@ -369,6 +374,7 @@ final class CItemData {
 			'zabbix[preprocessing_queue]',
 			'zabbix[process,<type>,<mode>,<state>]',
 			'zabbix[proxy,<name>,<param>]',
+			'zabbix[proxy,discovery]',
 			'zabbix[proxy_history]',
 			'zabbix[queue,<from>,<to>]',
 			'zabbix[rcache,<cache>,<mode>]',
@@ -771,25 +777,25 @@ final class CItemData {
 				]
 			],
 			'for_http_auth_type' => [
-				HTTPTEST_AUTH_BASIC => [
+				ZBX_HTTP_AUTH_BASIC => [
 					'js-item-http-username-label',
 					'js-item-http-username-field',
 					'js-item-http-password-label',
 					'js-item-http-password-field'
 				],
-				HTTPTEST_AUTH_NTLM => [
+				ZBX_HTTP_AUTH_NTLM => [
 					'js-item-http-username-label',
 					'js-item-http-username-field',
 					'js-item-http-password-label',
 					'js-item-http-password-field'
 				],
-				HTTPTEST_AUTH_KERBEROS => [
+				ZBX_HTTP_AUTH_KERBEROS => [
 					'js-item-http-username-label',
 					'js-item-http-username-field',
 					'js-item-http-password-label',
 					'js-item-http-password-field'
 				],
-				HTTPTEST_AUTH_DIGEST => [
+				ZBX_HTTP_AUTH_DIGEST => [
 					'js-item-http-username-label',
 					'js-item-http-username-field',
 					'js-item-http-password-label',
@@ -1156,10 +1162,18 @@ final class CItemData {
 				'description' => _('Operating system information. Returns string'),
 				'value_type' => ITEM_VALUE_TYPE_STR
 			],
+			'system.sw.os.get' => [
+				'description' => _('Operating system version information. Returns JSON'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'system.sw.packages[<regexp>,<manager>,<format>]' => [
 				'description' => _('Listing of installed packages. Returns text'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
+			'system.sw.packages.get[<regexp>,<manager>]' => [
+				'description' => _('Detailed listing of installed packages. Returns text in JSON format'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'system.swap.in[<device>,<type>]' => [
 				'description' => _('Swap in (from device into memory) statistics. Returns integer'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
@@ -1764,11 +1778,11 @@ final class CItemData {
 				'description' => _('Find string on a web page. Returns the matched string, or as specified by the optional output parameter'),
 				'value_type' => ITEM_VALUE_TYPE_STR
 			],
-			'wmi.get[<namespace>,<query>]' => [
+			'wmi.get[namespace,query]' => [
 				'description' => _('Execute WMI query and return the first selected object. Returns integer, float, string or text (depending on the request)'),
 				'value_type' => null
 			],
-			'wmi.getall[<namespace>,<query>]' => [
+			'wmi.getall[namespace,query]' => [
 				'description' => _('Execute WMI query and return the JSON document with all selected objects'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
@@ -1784,6 +1798,10 @@ final class CItemData {
 				'description' => _('Startup time of Zabbix server, Unix timestamp.'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
 			],
+			'zabbix[connector_queue]' => [
+				'description' => _('Count of values enqueued in the connector queue.'),
+				'value_type' => ITEM_VALUE_TYPE_UINT64
+			],
 			'zabbix[host,,items]' => [
 				'description' => _('Number of enabled items on the host.'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
@@ -1836,6 +1854,10 @@ final class CItemData {
 				'description' => _('Time of proxy last access. Name - proxy name. Valid params are: lastaccess - Unix timestamp, delay - seconds.'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
 			],
+			'zabbix[proxy,discovery]' => [
+				'description' => _('List of Zabbix proxies with name, mode, encryption, compression, version, last seen, host count, item count, required values per second (vps) and compatibility (current/outdated/unsupported). Returns JSON.'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'zabbix[proxy_history]' => [
 				'description' => _('Number of items in proxy history that are not yet sent to the server'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
