@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,26 +35,26 @@ $filter_tags_table = CTagFilterFieldHelper::getTagFilterField([
 	'tags' => $filter_tags
 ]);
 
-$filter = new CFilter(new CUrl('templates.php'));
-$filter
+$filter = (new CFilter())
+	->setResetUrl(new CUrl('templates.php'))
 	->setProfile($data['profileIdx'])
 	->setActiveTab($data['active_tab'])
 	->addFilterTab(_('Filter'), [
 		(new CFormList())
 			->addRow(
-				(new CLabel(_('Host groups'), 'filter_groups__ms')),
+				(new CLabel(_('Template groups'), 'filter_groups__ms')),
 				(new CMultiSelect([
 					'name' => 'filter_groups[]',
-					'object_name' => 'hostGroup',
+					'object_name' => 'templateGroup',
 					'data' => $data['filter']['groups'],
 					'popup' => [
 						'parameters' => [
-							'srctbl' => 'host_groups',
+							'srctbl' => 'template_groups',
 							'srcfld1' => 'groupid',
-							'dstfrm' => $filter->getName(),
+							'dstfrm' => 'zbx_filter',
 							'dstfld1' => 'filter_groups_',
-							'templated_hosts' => 1,
-							'editable' => 1,
+							'with_templates' => true,
+							'editable' => true,
 							'enrich_parent_groups' => true
 						]
 					]
@@ -71,7 +71,7 @@ $filter
 							'srctbl' => 'templates',
 							'srcfld1' => 'hostid',
 							'srcfld2' => 'host',
-							'dstfrm' => $filter->getName(),
+							'dstfrm' => 'zbx_filter',
 							'dstfld1' => 'filter_templates_'
 						]
 					]
@@ -79,24 +79,40 @@ $filter
 			)
 			->addRow(_('Name'),
 				(new CTextBox('filter_name', $data['filter']['name']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+			)
+			->addRow(_('Vendor'),
+				(new CTextBox('filter_vendor_name', $data['filter']['vendor_name'], false,
+					DB::getFieldLength('hosts', 'vendor_name')
+				))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+			)
+			->addRow(_('Version'),
+				(new CTextBox('filter_vendor_version', $data['filter']['vendor_version'], false,
+					DB::getFieldLength('hosts', 'vendor_version'))
+				)->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
 			),
 		(new CFormList())->addRow(_('Tags'), $filter_tags_table)
 	]);
 
-$widget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('Templates'))
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::DATA_COLLECTION_TEMPLATES_LIST))
 	->setControls((new CTag('nav', true,
 		(new CList())
 			->addItem(new CRedirectButton(_('Create template'),
 				(new CUrl('templates.php'))
 					->setArgument('groupids', array_keys($data['filter']['groups']))
 					->setArgument('form', 'create')
-					->getUrl()
 				)
 			)
 			->addItem(
 				(new CButton('form', _('Import')))
-					->onClick('return PopUp("popup.import", {rules_preset: "template"}, null, this);')
+					->onClick('return PopUp("popup.import", {
+						rules_preset: "template", "'.
+						CCsrfTokenHelper::CSRF_TOKEN_NAME.'": "'.CCsrfTokenHelper::get('import').'"
+					}, {
+						dialogueid: "popup_import",
+						dialogue_class: "modal-popup-generic"
+					});')
 					->removeId()
 			)
 		))->setAttribute('aria-label', _('Content controls'))
@@ -121,6 +137,8 @@ $table = (new CTableInfo())
 		_('Dashboards'),
 		_('Discovery'),
 		_('Web'),
+		_('Vendor'),
+		_('Version'),
 		_('Linked templates'),
 		_('Linked to templates'),
 		_('Tags')
@@ -195,7 +213,8 @@ foreach ($data['templates'] as $template) {
 		[
 			$data['allowed_ui_conf_hosts']
 				? new CLink(_('Hosts'),
-					(new CUrl('hosts.php'))
+					(new CUrl('zabbix.php'))
+						->setArgument('action', 'host.list')
 						->setArgument('filter_set', '1')
 						->setArgument('filter_templates', [$template['templateid']])
 				)
@@ -256,6 +275,8 @@ foreach ($data['templates'] as $template) {
 			),
 			CViewHelper::showNum($template['httpTests'])
 		],
+		$template['vendor_name'],
+		$template['vendor_version'],
 		$linked_templates_output,
 		$linked_to_output,
 		$data['tags'][$template['templateid']]
@@ -276,18 +297,28 @@ $form->addItem([
 			],
 			'popup.massupdate.template' => [
 				'content' => (new CButton('', _('Mass update')))
-					->onClick("return openMassupdatePopup(this, 'popup.massupdate.template');")
+					->onClick(
+						"openMassupdatePopup('popup.massupdate.template', ".
+							json_encode([CCsrfTokenHelper::CSRF_TOKEN_NAME => CCsrfTokenHelper::get('template')]).
+						", {
+							dialogue_class: 'modal-popup-static',
+							trigger_element: this
+						});"
+					)
 					->addClass(ZBX_STYLE_BTN_ALT)
 					->removeAttribute('id')
 			],
-			'template.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected templates?')],
+			'template.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected templates?'),
+				'csrf_token' => CCsrfTokenHelper::get('templates.php')
+			],
 			'template.massdeleteclear' => ['name' => _('Delete and clear'),
-				'confirm' => _('Delete and clear selected templates? (Warning: all linked hosts will be cleared!)')
+				'confirm' => _('Delete and clear selected templates? (Warning: all linked hosts will be cleared!)'),
+				'csrf_token' => CCsrfTokenHelper::get('templates.php')
 			]
 		]
 	)
 ]);
 
-$widget->addItem($form);
-
-$widget->show();
+$html_page
+	->addItem($form)
+	->show();
