@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2019 Zabbix SIA
+ ** Copyright (C) 2001-2023 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -35,10 +35,10 @@
 			var elm = $('#flickerfreescreen_'+id);
 
 			if (in_progress) {
-				elm.addClass('in-progress delayed-15s');
+				elm.addClass('is-loading is-loading-fadein delayed-15s');
 			}
 			else {
-				elm.removeClass('in-progress delayed-15s');
+				elm.removeClass('is-loading is-loading-fadein delayed-15s');
 			}
 		},
 
@@ -74,6 +74,16 @@
 			}
 		},
 
+		remove: function(screen) {
+			if (typeof screen.id !== 'undefined' && typeof this.screens[screen.id] !== 'undefined') {
+				if (typeof this.screens[screen.id].timeoutHandler !== 'undefined') {
+					window.clearTimeout(this.screens[screen.id].timeoutHandler);
+				}
+
+				delete this.screens[screen.id];
+			}
+		},
+
 		refresh: function(id) {
 			var screen = this.screens[id];
 
@@ -81,34 +91,47 @@
 				return;
 			}
 
+			// Do not update screen if displaying static hintbox.
+			if ($('#flickerfreescreen_' + id + ' [data-expanded="true"]').length) {
+				if (screen.isFlickerfree && screen.interval > 0) {
+					clearTimeout(screen.timeoutHandler);
+					screen.timeoutHandler = setTimeout(() => flickerfreeScreen.refresh(id), 1000);
+				}
+
+				return;
+			}
+
 			/**
 			 * 17   SCREEN_RESOURCE_HISTORY
 			 * 21   SCREEN_RESOURCE_HTTPTEST_DETAILS
 			 * 22   SCREEN_RESOURCE_DISCOVERY
 			 * 23   SCREEN_RESOURCE_HTTPTEST
-			 * 24   SCREEN_RESOURCE_PROBLEM
 			 */
 			var type_params = {
 					'17': ['mode', 'resourcetype', 'pageFile', 'page'],
 					'21': ['mode', 'resourcetype', 'profileIdx2'],
 					'22': ['mode', 'resourcetype', 'data'],
-					'23': ['mode', 'groupid', 'hostid', 'resourcetype', 'data', 'page'],
-					'24': ['mode', 'resourcetype', 'data', 'page'],
+					'23': ['mode', 'resourcetype', 'data', 'page'],
 					'default': ['mode', 'screenid', 'groupid', 'hostid', 'pageFile', 'profileIdx', 'profileIdx2',
 						'screenitemid'
 					]
 				},
-				params_index = type_params[screen.resourcetype] ? screen.resourcetype : 'default';
-				ajax_url = new Curl('jsrpc.php'),
+				params_index = type_params[screen.resourcetype] ? screen.resourcetype : 'default',
 				self = this;
 
-			ajax_url.setArgument('type', 9); // PAGE_TYPE_TEXT
-			ajax_url.setArgument('method', 'screen.get');
-			// TODO: remove, do not use timestamp passing to server and back to ensure newest content will be shown.
-			ajax_url.setArgument('timestamp', screen.timestampActual);
+			const ajax_url = new Curl('jsrpc.php');
+			const post_data = {
+				type: 9, // PAGE_TYPE_TEXT
+				method: 'screen.get',
+
+				// TODO: remove, do not use timestamp passing to server and back to ensure newest content will be shown.
+				timestamp: screen.timestampActual
+			};
 
 			$.each(type_params[params_index], function (i, name) {
-				ajax_url.setArgument(name, empty(screen[name]) ? null : screen[name]);
+				if (!empty(screen[name])) {
+					post_data[name] = screen[name];
+				}
 			});
 
 			// set actual timestamp
@@ -116,9 +139,9 @@
 
 			// timeline params
 			// SCREEN_RESOURCE_HTTPTEST_DETAILS, SCREEN_RESOURCE_DISCOVERY, SCREEN_RESOURCE_HTTPTEST
-			if (jQuery.inArray(screen.resourcetype, [21, 22, 23]) === -1) {
-				ajax_url.setArgument('from', screen.timeline.from);
-				ajax_url.setArgument('to', screen.timeline.to);
+			if ($.inArray(screen.resourcetype, [21, 22, 23]) === -1) {
+				post_data.from = screen.timeline.from;
+				post_data.to = screen.timeline.to;
 			}
 
 			switch (parseInt(screen.resourcetype, 10)) {
@@ -129,7 +152,7 @@
 					self.refreshImg(id, function() {
 						$('a', '#flickerfreescreen_' + id).each(function() {
 								var obj = $(this),
-								url = new Curl(obj.attr('href'), false);
+								url = new Curl(obj.attr('href'));
 
 								url.setArgument('from', screen.timeline.from);
 								url.setArgument('to', screen.timeline.to);
@@ -144,16 +167,6 @@
 					self.refreshMap(id);
 					break;
 
-				// SCREEN_RESOURCE_PLAIN_TEXT
-				case 3:
-					self.refreshHtml(id, ajax_url);
-					break;
-
-				// SCREEN_RESOURCE_CLOCK
-				case 7:
-					// don't refresh anything
-					break;
-
 				// SCREEN_RESOURCE_HISTORY
 				case 17:
 					if (screen.data.action == 'showgraph') {
@@ -163,63 +176,38 @@
 						if ('itemids' in screen.data) {
 							$.each(screen.data.itemids, function (i, value) {
 								if (!empty(value)) {
-									ajax_url.setArgument('itemids[' + value + ']', value);
+									post_data['itemids[' + value + ']'] = value;
 								}
 							});
 						}
 						else {
-							ajax_url.setArgument('graphid', screen.data.graphid);
+							post_data['graphid'] = screen.data.graphid;
 						}
 
 						$.each({
 							'filter': screen.data.filter,
 							'filter_task': screen.data.filterTask,
 							'mark_color': screen.data.markColor,
-							'page': screen.data.page,
 							'action': screen.data.action
 						}, function (ajax_key, value) {
 							if (!empty(value)) {
-								ajax_url.setArgument(ajax_key, value);
+								post_data[ajax_key] = value;
 							}
 						});
 
-						self.refreshHtml(id, ajax_url);
+						self.refreshHtml(id, ajax_url, post_data);
 					}
 					break;
 
-				// SCREEN_RESOURCE_CHART
-				case 18:
-					self.refreshImg(id);
-					break;
-
-				// SCREEN_RESOURCE_SCREEN
-				// SCREEN_RESOURCE_LLD_SIMPLE_GRAPH
-				// SCREEN_RESOURCE_LLD_GRAPH
-				case 8:
-				case 20:
-				case 19:
-					self.refreshProfile(id, ajax_url);
-					break;
-
 				default:
-					self.refreshHtml(id, ajax_url);
+					self.refreshHtml(id, ajax_url, post_data);
 					break;
 			}
 
 			// set next refresh execution time
 			if (screen.isFlickerfree && screen.interval > 0) {
 				clearTimeout(screen.timeoutHandler);
-
-				screen.timeoutHandler = window.setTimeout(
-					function() {
-						window.flickerfreeScreen.refresh(id);
-					},
-					screen.interval
-				);
-
-				// refresh time control actual time
-				clearTimeout(timeControl.timeRefreshTimeoutHandler);
-				timeControl.refreshTime();
+				screen.timeoutHandler = setTimeout(() => flickerfreeScreen.refresh(id), screen.interval);
 			}
 		},
 
@@ -228,13 +216,18 @@
 				var screen = this.screens[id];
 
 				if (!empty(screen.id) && typeof screen.timeline !== 'undefined') {
-					screen.timeline = jQuery.extend(screen.timeline, {
+					screen.timeline = $.extend(screen.timeline, {
 						from: time_object.from,
 						to: time_object.to,
 						from_ts: time_object.from_ts,
 						to_ts: time_object.to_ts
 					});
 
+					// Reset pager on time range update (SCREEN_RESOURCE_HISTORY).
+					if (screen.resourcetype == 17) {
+						screen.page = 1;
+					}
+
 					// restart refresh execution starting from Now
 					clearTimeout(screen.timeoutHandler);
 					this.refresh(id);
@@ -242,7 +235,7 @@
 			}
 		},
 
-		refreshHtml: function(id, ajaxUrl) {
+		refreshHtml: function(id, ajaxUrl, post_data = {}) {
 			var screen = this.screens[id],
 				request_start = new CDate().getTime();
 
@@ -258,7 +251,7 @@
 					url: ajaxUrl.getUrl(),
 					type: 'post',
 					cache: false,
-					data: {},
+					data: post_data,
 					dataType: 'html',
 					success: function(html) {
 						var html = $(html);
@@ -268,9 +261,9 @@
 							screen.timestamp = request_start;
 							screen.isRefreshing = false;
 
-							$('main .msg-bad').remove();
+							$('.wrapper > .msg-bad').remove();
 							$('#flickerfreescreen_' + id).replaceWith(html);
-							$('main .msg-bad').insertBefore('main > :first-child');
+							html.filter('.msg-bad').insertBefore('.wrapper main');
 
 							window.flickerfreeScreen.setElementProgressState(id, false);
 						}
@@ -295,7 +288,7 @@
 		},
 
 		refreshMap: function(id) {
-			var screen = this.screens[id], self = this;
+			var screen = this.screens[id];
 
 			if (screen.isRefreshing) {
 				this.calculateReRefresh(id);
@@ -310,7 +303,7 @@
 				var url = new Curl(screen.data.options.refresh);
 				url.setArgument('curtime', new CDate().getTime());
 
-				jQuery.ajax({
+				$.ajax({
 					'url': url.getUrl()
 				})
 				.fail(function() {
@@ -344,7 +337,7 @@
 
 				$('img', '#flickerfreescreen_' + id).each(function() {
 					var domImg = $(this),
-						url = new Curl(domImg.attr('src'), false),
+						url = new Curl(domImg.attr('src')),
 						zbx_sbox = domImg.data('zbx_sbox');
 
 					if (zbx_sbox && zbx_sbox.prevent_refresh) {
@@ -360,8 +353,8 @@
 					url.setArgument('_', request_start.toString(34));
 
 					// Create temp image in buffer.
-					var	img = $('<img/>', {
-							'class': domImg.attr('class'),
+					var	img = $('<img>', {
+							class: domImg.attr('class'),
 							id: domImg.attr('id'),
 							name: domImg.attr('name'),
 							border: domImg.attr('border'),
@@ -409,7 +402,7 @@
 					}
 
 					if (zbx_sbox) {
-						img.data('zbx_sbox', jQuery.extend(zbx_sbox, {
+						img.data('zbx_sbox', $.extend(zbx_sbox, {
 							from: screen.timeline.from,
 							from_ts: screen.timeline.from_ts,
 							to: screen.timeline.to,
@@ -421,7 +414,7 @@
 		},
 
 		/**
-		 * Getting shadow box height of graph image, asynchronious. Only for line graphs on dashboard.
+		 * Getting shadow box height of graph image, asynchronous. Only for line graphs on dashboard.
 		 * Will return xhr request for line graphs.
 		 *
 		 * @param {Curl}     url  Curl object for image request.
@@ -445,38 +438,6 @@
 			return null;
 		},
 
-		refreshProfile: function(id, ajaxUrl) {
-			var screen = this.screens[id];
-
-			if (screen.isRefreshing) {
-				this.calculateReRefresh(id);
-			}
-			else {
-				screen.isRefreshing = true;
-				screen.timestampResponsiveness = new CDate().getTime();
-
-				var ajaxRequest = $.ajax({
-					url: ajaxUrl.getUrl(),
-					type: 'post',
-					data: {},
-					success: function(data) {
-						screen.timestamp = new CDate().getTime();
-						screen.isRefreshing = false;
-					},
-					error: function() {
-						window.flickerfreeScreen.calculateReRefresh(id);
-					}
-				});
-
-				$.when(ajaxRequest).always(function() {
-					if (screen.isReRefreshRequire) {
-						screen.isReRefreshRequire = false;
-						window.flickerfreeScreen.refresh(id);
-					}
-				});
-			}
-		},
-
 		calculateReRefresh: function(id) {
 			var screen = this.screens[id],
 				time = new CDate().getTime();
@@ -507,8 +468,8 @@
 			this.screens = [];
 
 			for (var id in timeControl.objectList) {
-				if (id !== 'scrollbar' && timeControl.objectList.hasOwnProperty(id)) {
-					delete timeControl.objectList[id];
+				if (timeControl.objectList.hasOwnProperty(id)) {
+					timeControl.removeObject(id);
 				}
 			}
 		}
